[manpage_begin tktray n 1.0]
[copyright {2005, Anton Kovalenko}]
[moddesc   {tktray}]
[titledesc {System Tray Icon Support for Tk on X11}]
[require Tcl 8.4]
[require tktray [opt 1.0]]
[description]
[para]

Tktray is an extension that is able to create system tray icons.
It follows [uri http://www.freedesktop.org]
specifications when looking up the system tray 
manager. This protocol is supported by modern versions
of KDE and Gnome panels, and by some other panel-like application.

[section COMMANDS]

[list_begin definitions]

[call [cmd "tktray::icon"] [arg pathName] [opt [arg options]]]

Create a new icon for the system tray. 
The application managing the system tray is notified about the new icon.
It normally results in the icon being added to the tray.

If there is no system tray at the icon creation time,
the icon will be invisible. When a new system tray appears, the icon will 
be added to it.

[list_begin opt]
[opt_def "-class"]
   WM_CLASS attribute for the icon window. Tray manager may use class name
   to remember icon position or other attributes. 

[opt_def "-image"]
   image to show in the system tray. The value must be the name of a photo image.
   Transparency data of the photo are used to set the window's shape.

   The icon will be automatically redrawn or resized 
   appropriately on any image modifications.

[opt_def "-visible"]
   boolean value indicating whether the icon must be visible. 
   The system tray manager continues to manage the icon whether it is
   visible or not. Thus  when invisible icon becomes visible, its position
   on the system tray is likely to remain the same.

[list_end]

[call [arg pathName] [method configure] [opt [arg options]]]
   
   Modify icon's options after it was created. 

[call [arg pathName] [method bbox]]
   
   Get the list of left, top, right and bottom coordinates of the icon
   relative to the root window of the icon's screen.

   This command should be used in preference to [cmd "winfo rootx"] and 
   [cmd "winfo rooty"] to get icon location.
   No X11 events are delivered to the application when an
   ancestor window of an icon is resized or moved;
   thus Tk may have incorrect information about root coordinates of the window.

[list_end]

[section "WINDOW MANAGEMENT"]
   An icon behaves like a toplevel window with respect to the 
   Tk [cmd wm] and [cmd winfo] commands. To get up-to-date information
   about the icon's screen coordinates, use [cmd bbox] subcommand rather than 
   [cmd "winfo rootx"] and [cmd "winfo rooty"].

   When [arg -image] option is used, the window minimal size and shape
   are set using the dimensions and transparency information of the photo 
   image. [cmd "wm minsize"] command may be used to set the minimal icon size
   when no image is given. Panel applications obey this setting usually.

   Like any toplevel window, the icon may contain widgets. 
   It's not recommended to build complex GUIs in the system tray. Also note
   that the correct handling of the keyboard input is unlikely to be possible.

[section AUTHORS]
Anton Kovalenko
See [uri http://www.sw4me.com/wiki/Tktray].
[para]

[keywords icons taskbar "system tray"]

[manpage_end]
